@@ -1,3 +1,4 @@
+use super::bytemerge;
 use super::log;
 use super::result;
 
@@ -41,3 +42,13 @@ fn test_result() {
         Err(err) => assert_eq!(err, error),
     };
 }
+
+#[test]
+fn test_bytemerge() {
+    assert_eq!(
+        bytemerge::bytemerge(&[0xFF, 0xFF, 0xFF, 0xFF]).unwrap(),
+        0xFFFFFFFF
+    );
+
+    assert_eq!(bytemerge::bytemerge(&[0xFF, 0xFF]).unwrap(), 0xFFFF);
+}
